@@ -23,6 +23,9 @@
  */
 
 #include <linux/version.h>
+#if LINUX_VERSION_CODE >= KERNEL_VERSION(2, 6, 18)
+#include <linux/autoconf.h>
+#endif
 
 #if LINUX_VERSION_CODE < KERNEL_VERSION(2, 2, 3)
 #error "This driver requires Linux 2.2.3 or higher."
@@ -133,11 +136,16 @@ typedef __u32 __be32;
 #endif
 #ifndef list_for_each_entry
 #define list_for_each_entry(pos, head, member)                          \
-        for (pos = list_entry((head)->next, typeof(*pos), member),      \
-                     prefetch(pos->member.next);                        \
-             &pos->member != (head);                                    \
-             pos = list_entry(pos->member.next, typeof(*pos), member),  \
-                     prefetch(pos->member.next))
+	for (pos = list_entry((head)->next, typeof(*pos), member);	\
+	     prefetch(pos->member.next), &pos->member != (head);	\
+	     pos = list_entry(pos->member.next, typeof(*pos), member))
+#endif
+#ifndef list_for_each_entry_safe
+#define list_for_each_entry_safe(pos, n, head, member)			\
+	for (pos = list_entry((head)->next, typeof(*pos), member),	\
+		n = list_entry(pos->member.next, typeof(*pos), member);	\
+	     &pos->member != (head);					\
+	     pos = n, n = list_entry(n->member.next, typeof(*n), member))
 #endif
 #ifndef list_for_each_prev
 #define list_for_each_prev(pos, head) \
@@ -157,6 +165,10 @@ typedef __u32 __be32;
 #define __initdata_or_module
 #endif
 
+#ifndef va_copy
+#define va_copy __va_copy
+#endif
+
 #include <linux/kdev_t.h>
 #ifndef major
 #define major(x) MAJOR(x)
@@ -247,7 +259,8 @@ static inline struct proc_dir_entry *PDE(const struct inode *inode)
 #endif
 #endif
 
-#if LINUX_VERSION_CODE < KERNEL_VERSION(2, 6, 14)
+#if LINUX_VERSION_CODE < KERNEL_VERSION(2, 6, 14) && \
+	!defined(CONFIG_HAVE_GFP_T)
 typedef unsigned __nocast gfp_t;
 #endif
 
@@ -399,10 +412,10 @@ static inline void synchronize_irq_wrapper(unsigned int irq) { synchronize_irq()
 #define synchronize_irq(irq)	synchronize_irq_wrapper(irq)
 #endif /* LINUX_VERSION_CODE < 2.5.28 */
 #ifndef IRQ_NONE
-#define IRQ_NONE	/*void*/
-#define IRQ_HANDLED	/*void*/
-#define IRQ_RETVAL(x)	/*void*/
 typedef void irqreturn_t;
+#define IRQ_NONE
+#define IRQ_HANDLED
+#define IRQ_RETVAL(x)
 #endif
 #endif /* < 2.6.0 */
 
@@ -423,14 +436,39 @@ typedef void irqreturn_t;
 	_x > _y ? _x : _y; })
 #endif
 
+#ifndef min_t
+#define min_t(type,x,y) \
+	({ type __x = (x); type __y = (y); __x < __y ? __x: __y; })
+#define max_t(type,x,y) \
+	({ type __x = (x); type __y = (y); __x > __y ? __x: __y; })
+#endif
+
+#ifndef container_of
+#define container_of(ptr, type, member) ({			\
+	const typeof( ((type *)0)->member ) *__mptr = (ptr);	\
+	(type *)( (char *)__mptr - offsetof(type,member) );})
+#endif
+
 #ifndef ARRAY_SIZE
 #define ARRAY_SIZE(x) (sizeof(x) / sizeof((x)[0]))
 #endif
 
+#ifndef ALIGN
+#define ALIGN(x,a) (((x)+(a)-1)&~((a)-1))
+#endif
+
+#ifndef roundup
+#define roundup(x, y) ((((x) + ((y) - 1)) / (y)) * (y))
+#endif
+
 #ifndef BUG_ON
 #define BUG_ON(x) /* nothing */
 #endif
 
+#ifndef BUILD_BUG_ON
+#define BUILD_BUG_ON(condition) ((void)sizeof(char[1 - 2*!!(condition)]))
+#endif
+
 #if LINUX_VERSION_CODE < KERNEL_VERSION(2, 6, 0)
 #include <linux/devfs_fs_kernel.h>
 #ifdef CONFIG_DEVFS_FS
@@ -599,6 +637,7 @@ int snd_hack_usb_set_interface(struct usb_device *dev, int interface, int altern
 #if LINUX_VERSION_CODE < KERNEL_VERSION(2, 5, 45) && !defined(__WORK_INITIALIZER)
 #define SND_WORKQUEUE_COMPAT
 struct workqueue_struct;
+struct delayed_work;
 struct work_struct {
 	unsigned long pending;
 	struct list_head entry;
@@ -629,8 +668,12 @@ void snd_compat_destroy_workqueue(struct workqueue_struct *wq);
 #define destroy_workqueue(wq) snd_compat_destroy_workqueue((wq));
 int snd_compat_queue_work(struct workqueue_struct *wq, struct work_struct *work);
 #define queue_work(wq, work) snd_compat_queue_work((wq), (work))
-int snd_compat_queue_delayed_work(struct workqueue_struct *wq, struct work_struct *work, unsigned long delay);
+int snd_compat_queue_delayed_work(struct workqueue_struct *wq, struct delayed_work *work, unsigned long delay);
 #define queue_delayed_work(wq, work, delay) snd_compat_queue_delayed_work((wq), (work), (delay))
+#define schedule_delayed_work(work, delay) snd_compat_queue_delayed_work(NULL, (work), (delay))
+int snd_compat_cancel_delayed_work(struct delayed_work *work);
+#define cancel_delayed_work(work) snd_compat_cancel_delayed_work(work)
+#define flush_scheduled_work()
 #endif /* < 2.5.45 */
 #endif /* < 2.6.0 */
 
@@ -641,6 +684,31 @@ struct workqueue_struct *snd_compat_create_workqueue2(const char *name);
 #define create_workqueue(name) snd_compat_create_workqueue2(name)
 #endif
 
+#if LINUX_VERSION_CODE < KERNEL_VERSION(2, 6, 20)
+#include <linux/workqueue.h>
+/* redefine INIT_WORK() */
+static inline void snd_INIT_WORK(struct work_struct *w, void (*f)(struct work_struct *))
+{
+	INIT_WORK(w, (void(*)(void*))(f), w);
+}
+#undef INIT_WORK
+#define INIT_WORK(w,f) snd_INIT_WORK(w,f)
+/* delayed_work wrapper */
+struct delayed_work {
+	struct work_struct work;
+};
+#define INIT_DELAYED_WORK(_work, _func)	INIT_WORK(&(_work)->work, _func)
+#ifndef SND_WORKQUEUE_COMPAT
+/* redefine *_delayed_work() */
+#define queue_delayed_work(wq,_work,delay) \
+	queue_delayed_work(wq, &(_work)->work, delay)
+#define schedule_delayed_work(_work,delay) \
+	schedule_delayed_work(&(_work)->work, delay)
+#define cancel_delayed_work(_work) \
+	cancel_delayed_work(&(_work)->work)
+#endif /* !SND_WORKQUEUE_COMPAT */
+#endif /* < 2.6.20 */
+
 /* 2.5 new modules */
 #if LINUX_VERSION_CODE < KERNEL_VERSION(2, 5, 0)
 #define try_module_get(x) try_inc_mod_count(x)
@@ -687,6 +755,10 @@ static inline void *snd_compat_vmap(struct page **pages, unsigned int count, uns
 #define MODULE_ALIAS_CHARDEV_MAJOR(x)
 #endif
 
+#ifndef MODULE_FIRMWARE
+#define MODULE_FIRMWARE(x)
+#endif
+
 #ifndef CONFIG_HAVE_PCI_CONSISTENT_DMA_MASK
 #define pci_set_consistent_dma_mask(p,x) 0 /* success */
 #endif
@@ -947,6 +1019,7 @@ typedef u32 __bitwise pm_message_t;
 #define PCI_D2     2
 #define PCI_D3hot  3
 #define PCI_D3cold 4
+#define pci_choose_state(pci,state)	((state) ? PCI_D3hot : PCI_D0)
 #endif
 #endif
 #endif
@@ -1253,6 +1326,8 @@ static inline int snd_pnp_register_card_driver(struct pnp_card_driver *drv)
 #define down_write_nested(sem, subclass)	down_write(sem)
 #define down_read_non_owner(sem)		down_read(sem)
 #define up_read_non_owner(sem)			up_read(sem)
+#define spin_lock_nested(lock, x)		spin_lock(lock)
+#define spin_lock_irqsave_nested(lock, f, x)	spin_lock_irqsave(lock, f)
 #endif
 
 /*
@@ -1286,4 +1361,55 @@ static inline int snd_pci_enable_msi(struct pci_dev *dev) { return -1; }
 #define SEEK_END	2
 #endif
 
+/* kmemdup() wrapper */
+#if LINUX_VERSION_CODE < KERNEL_VERSION(2, 6, 19)
+#include <linux/string.h>
+static inline void *snd_kmemdup(const void *src, size_t len, gfp_t gfp)
+{
+	void *dst = kmalloc(len, gfp);
+	if (!dst)
+		return NULL;
+	memcpy(dst, src, len);
+	return dst;
+}
+#define kmemdup	snd_kmemdup
+#endif
+
+/* wrapper for new irq handler type */
+#ifndef CONFIG_SND_NEW_IRQ_HANDLER
+#include <linux/interrupt.h>
+typedef irqreturn_t (*snd_irq_handler_t)(int, void *);
+#undef irq_handler_t
+#define irq_handler_t snd_irq_handler_t
+int snd_request_irq(unsigned int, irq_handler_t handler,
+		    unsigned long, const char *, void *);
+void snd_free_irq(unsigned int, void *);
+#undef request_irq
+#define request_irq	snd_request_irq
+#undef free_irq
+#define free_irq	snd_free_irq
+extern struct pt_regs *snd_irq_regs;
+#define get_irq_regs()	snd_irq_regs
+#endif /* !CONFIG_SND_NEW_IRQ_HANDLER */
+
+/* pci_intx() wrapper */
+#if LINUX_VERSION_CODE < KERNEL_VERSION(2, 6, 14)
+#ifdef CONFIG_PCI
+#undef pci_intx
+#define pci_intx(pci,x)
+#endif
+#endif
+
+#if LINUX_VERSION_CODE < KERNEL_VERSION(2, 6, 20)
+#define CONFIG_SYSFS_DEPRECATED	1
+#endif
+
+#if LINUX_VERSION_CODE < KERNEL_VERSION(2, 6, 21)
+static inline __attribute__((const))
+int is_power_of_2(unsigned long n)
+{
+	return n != 0 && ((n & (n - 1)) == 0);
+}
+#endif
+
 #endif /* __SOUND_LOCAL_DRIVER_H */
