@@ -19,6 +19,9 @@
 
 Linux HPI driver module
 *******************************************************************************/
+#define SOURCEFILE_NAME "hpimod.c"
+#define HPIMOD_PCI_ENABLE_DEV 0
+
 #include "hpi.h"
 #include "hpidebug.h"
 #include "hpimsgx.h"
@@ -40,18 +43,18 @@ void snd_asihpi_unbind(adapter_t * hpi_card);
 #   define USE_SPINLOCK 1
 #endif
 
-/*  copy_to_user and friends can be used inside semaphore, but not inside spinlock 
+/*  copy_to_user and friends can be used inside semaphore, but not inside spinlock
     in which case, data must be copied to a local buffer outside the spinlock
 */
 #ifdef HPI_LOCKING
-#define COPY_TO_LOCAL 1
+#define HPIMOD_COPY_TO_LOCAL 1
 #endif
 
 #if (USE_SPINLOCK) && ! defined (HPI_LOCKING)
 /* HPI_LOCKING causes spinlocks in this file to be defined to noops,
  because locking is down inside hpi
 */
-#   define COPY_TO_LOCAL 1
+#   define HPIMOD_COPY_TO_LOCAL 1
 #    define SPIN_LOCK_INIT spin_lock_init
 #    define SPIN_LOCK_IRQSAVE spin_lock_irqsave
 #   define SPIN_UNLOCK_IRQRESTORE spin_unlock_irqrestore
@@ -59,16 +62,11 @@ void snd_asihpi_unbind(adapter_t * hpi_card);
 #    define SPIN_LOCK_INIT(a)
 #   define SPIN_LOCK_IRQSAVE(a,b)
 #   define SPIN_UNLOCK_IRQRESTORE(a,b)
-#   ifndef COPY_TO_LOCAL
-#      define COPY_TO_LOCAL 0
+#   ifndef HPIMOD_COPY_TO_LOCAL
+#      define HPIMOD_COPY_TO_LOCAL 0
 #   endif
 #endif
 
-/* Report elapsed time of messages to kernel log */
-#ifndef TIME_HPI_MESSAGES
-#   define TIME_HPI_MESSAGES 0
-#endif
-
 #ifndef HPIMOD_DEFAULT_BUF_SIZE
 #   define HPIMOD_DEFAULT_BUF_SIZE 192000
 #endif
@@ -91,8 +89,21 @@ MODULE_LICENSE("GPL");
 MODULE_AUTHOR("AudioScience <support@audioscience.com>");
 MODULE_DESCRIPTION("AudioScience HPI");
 
+#ifdef MODULE_FIRMWARE
+MODULE_FIRMWARE("asihpi/dsp2400.bin");
+MODULE_FIRMWARE("asihpi/dsp4100.bin");
+MODULE_FIRMWARE("asihpi/dsp4300.bin");
+MODULE_FIRMWARE("asihpi/dsp5000.bin");
+MODULE_FIRMWARE("asihpi/dsp6200.bin");
+MODULE_FIRMWARE("asihpi/dsp6205.bin");
+MODULE_FIRMWARE("asihpi/dsp6413.bin");
+MODULE_FIRMWARE("asihpi/dsp6600.bin");
+MODULE_FIRMWARE("asihpi/dsp8713.bin");
+MODULE_FIRMWARE("asihpi/dsp8900.bin");
+#endif
+
 static int major = 0;
-#if COPY_TO_LOCAL
+#if HPIMOD_COPY_TO_LOCAL
 static int bufsize = HPIMOD_DEFAULT_BUF_SIZE;
 #endif
 
@@ -101,13 +112,13 @@ static int bufsize = HPIMOD_DEFAULT_BUF_SIZE;
 MODULE_PARM(major, "i");
 MODULE_PARM(hpiDebugLevel, "0-6i");
 
-#if COPY_TO_LOCAL
+#if HPIMOD_COPY_TO_LOCAL
 MODULE_PARM(bufsize, "i");
 #endif
 
 #else				/* new style params */
 module_param(major, int, S_IRUGO);
-#if COPY_TO_LOCAL
+#if HPIMOD_COPY_TO_LOCAL
 module_param(bufsize, int, S_IRUGO);
 #endif
 /* Allow the debug level to be changed after module load.
@@ -123,7 +134,7 @@ MODULE_PARM_DESC(bufsize,
 		 "Buffer size to allocate for data transfer from HPI ioctl ");
 
 static int hpi_init(void);
-/* Spinlocks (interrupt disabling on uniprocessor) supposed to prevent contention within and between ALSA 
+/* Spinlocks (interrupt disabling on uniprocessor) supposed to prevent contention within and between ALSA
    or other kernel interrupt contexts and single userspace HPI program that made it past the semaphore.
    These are also needed when multiple ALSA streams are running
 */
@@ -134,8 +145,11 @@ static adapter_t adapters[HPI_MAX_ADAPTERS];
 
 #define HOWNER_KERNEL ((void *)-1)
 
+/* Ludwig Schwardt suggests using current->tgid instead of *file as the owner
+identifier in issue #340 */
+
 /* Wrapper function to HPI_Message to enable dumping of the
-   message and response types.  
+   message and response types.
 */
 static void HPI_MessageF(HPI_MESSAGE * phm,
 			 HPI_RESPONSE * phr, struct file *file)
@@ -211,7 +225,7 @@ static int hpi_ioctl(struct inode *inode, struct file *file,
 	u32 uncopied_bytes;
 	adapter_t *pa;
 
-#if  (COPY_TO_LOCAL!=1)
+#if  (HPIMOD_COPY_TO_LOCAL!=1)
 	mm_segment_t fs;
 #endif
 	if (cmd != HPI_IOCTL_LINUX)
@@ -224,8 +238,8 @@ static int hpi_ioctl(struct inode *inode, struct file *file,
 	get_user(phr, &phpi_ioctl_data->phr);
 
 	/* Now read the message size and data from user space.  */
-	get_user(hm.wSize, (u16 __user *) phm);
-	uncopied_bytes = copy_from_user(&hm, phm, hm.wSize);
+	/* get_user(hm.wSize, (u16 __user *)phm); */
+	uncopied_bytes = copy_from_user(&hm, phm, sizeof(hm));
 	if (uncopied_bytes)
 		return -EFAULT;
 
@@ -233,7 +247,7 @@ static int hpi_ioctl(struct inode *inode, struct file *file,
 		HPI_InitResponse(&hr, HPI_OBJ_ADAPTER, HPI_ADAPTER_OPEN,
 				 HPI_ERROR_BAD_ADAPTER_NUMBER);
 		/* Copy the response back to user space.  */
-		uncopied_bytes = copy_to_user(phr, &hr, hr.wSize);
+		uncopied_bytes = copy_to_user(phr, &hr, sizeof(hr));
 		if (uncopied_bytes)
 			return -EFAULT;
 		return 0;
@@ -252,16 +266,19 @@ static int hpi_ioctl(struct inode *inode, struct file *file,
 		switch (hm.wFunction) {
 		case HPI_OSTREAM_WRITE:
 		case HPI_ISTREAM_READ:
-			ptr = (u16 __user *) hm.u.d.u.Data.dwpbData;
+			/* Yes, sparse, this is correct. */
+			ptr = (u16 __user *) hm.u.d.u.Data.pbData;
 			size = hm.u.d.u.Data.dwDataSize;
 			//printk("HPI data size %ld\n",size);
 
-#if (COPY_TO_LOCAL)
-			hm.u.d.u.Data.dwpbData = (u32) pa->pBuffer;
-			if (size > bufsize) {
-				size = bufsize;
-				hm.u.d.u.Data.dwDataSize = size;
-			}
+#if (HPIMOD_COPY_TO_LOCAL)
+			hm.u.d.u.Data.pbData = pa->pBuffer;
+			/*
+			   if (size > bufsize) {
+			   size = bufsize;
+			   hm.u.d.u.Data.dwDataSize = size;
+			   }
+			 */
 #endif
 
 			if (hm.wFunction == HPI_ISTREAM_READ)	// from card, WRITE to user mem
@@ -270,31 +287,6 @@ static int hpi_ioctl(struct inode *inode, struct file *file,
 				wrflag = 0;
 			break;
 
-#ifdef HAS_AES18
-		case HPI_CONTROL_SET_STATE:
-			ptr =
-			    (u16 *) hm.u.cx.u.aes18tx_send_message.dwpbMessage;
-			size = hm.u.cx.u.aes18tx_send_message.wMessageLength;
-			wrflag = 0;
-#if (COPY_TO_LOCAL)
-			(char *)hm.u.cx.u.aes18tx_send_message.dwpbMessage =
-			    pa->pBuffer;
-#endif
-			break;
-
-		case HPI_CONTROL_GET_STATE:
-			ptr = (u16 *) hm.u.cx.u.aes18rx_get_message.dwpbMessage;
-			size =
-			    (u16 *) hm.u.cx.u.aes18rx_get_message.
-			    wMessageLength;
-			wrflag = 1;
-#if (COPY_TO_LOCAL)
-			(char *)hm.u.cx.u.aes18rx_get_message.dwpbMessage =
-			    pa->pBuffer;
-#endif
-			break;
-#endif
-
 		default:
 			break;
 		}
@@ -306,7 +298,7 @@ static int hpi_ioctl(struct inode *inode, struct file *file,
 			if (down_interruptible(&adapters[nAdapter].sem))
 				return (-EINTR);
 
-#if  (COPY_TO_LOCAL!=1)
+#if  (HPIMOD_COPY_TO_LOCAL!=1)
 			fs = get_fs();
 			set_fs(get_ds());
 			if (!access_ok
@@ -319,9 +311,17 @@ static int hpi_ioctl(struct inode *inode, struct file *file,
 			HPI_MessageF(&hm, &hr, file);
 
 			set_fs(fs);
-#else				//  COPY_TO_LOCAL==1
+#else				//  HPIMOD_COPY_TO_LOCAL==1
 			if (wrflag == 0) {
 
+				if (size > bufsize) {
+					up(&adapters[nAdapter].sem);
+					HPI_DEBUG_LOG2(WARNING,
+						       "Requested transfer of %d bytes, but max buffer size in %d bytes, returning error.\n",
+						       size, bufsize);
+					return -EINVAL;
+				}
+
 				uncopied_bytes =
 				    copy_from_user(pa->pBuffer, ptr, size);
 				if (uncopied_bytes) {
@@ -334,7 +334,16 @@ static int hpi_ioctl(struct inode *inode, struct file *file,
 			HPI_MessageF(&hm, &hr, file);
 
 			if (wrflag == 1) {
-				u32 uncopied_bytes;
+				//u32 uncopied_bytes;
+
+				if (size > bufsize) {
+					up(&adapters[nAdapter].sem);
+					HPI_DEBUG_LOG2(WARNING,
+						       "Requested transfer of %d bytes, but max buffer size in %d bytes, returning error.\n",
+						       size, bufsize);
+					return -EINVAL;
+				}
+
 				uncopied_bytes =
 				    copy_to_user(ptr, pa->pBuffer, size);
 				if (uncopied_bytes) {
@@ -343,7 +352,7 @@ static int hpi_ioctl(struct inode *inode, struct file *file,
 						       uncopied_bytes, size);
 				}
 			}
-#endif				// else COPY_TO_LOCAL==1
+#endif				// else HPIMOD_COPY_TO_LOCAL==1
 
 			up(&adapters[nAdapter].sem);
 		}
@@ -354,7 +363,7 @@ static int hpi_ioctl(struct inode *inode, struct file *file,
 		return -EFAULT;
 
 	/* Copy the response back to user space.  */
-	uncopied_bytes = copy_to_user(phr, &hr, hr.wSize);
+	uncopied_bytes = copy_to_user(phr, &hr, sizeof(hr));
 	if (uncopied_bytes)
 		return -EFAULT;
 	return 0;
@@ -419,16 +428,25 @@ static int __devinit adapter_probe(struct pci_dev *pci_dev,
 	HPI_MESSAGE hm;
 	HPI_RESPONSE hr;
 	adapter_t adapter;
+	HPI_PCI Pci;
 
 	memset(&adapter, 0, sizeof(adapter));
 
+#if HPIMOD_PCI_ENABLE_DEV
+	if ((err = pci_enable_device(pci_dev)) < 0)
+		return err;
+	pci_set_master(pci_dev);
+	if ((err = pci_request_regions(pci_dev, "asihpi")) < 0)
+		return err;
+#endif
+
 	printk(KERN_DEBUG "Probe PCI device (%04x:%04x,%04x:%04x,%04x)\n",
 	       pci_dev->vendor, pci_dev->device, pci_dev->subsystem_vendor,
 	       pci_dev->subsystem_device, pci_dev->devfn);
 
 	if (HPI_SubSysCreate() == NULL) {
 		printk(KERN_ERR "SubSysCreate failed.\n");
-		return -ENODEV;
+		goto err;
 	}
 
 	HPI_InitMessage(&hm, HPI_OBJ_SUBSYSTEM, HPI_SUBSYS_CREATE_ADAPTER);
@@ -439,44 +457,43 @@ static int __devinit adapter_probe(struct pci_dev *pci_dev,
 
 	// fill in HPI_PCI information from kernel provided information
 	for (idx = 0; idx < HPI_MAX_ADAPTER_MEM_SPACES; idx++) {
-		HPI_DEBUG_LOG4(DEBUG, "Resource %d %s %lx-%lx\n", idx,
+		HPI_DEBUG_LOG4(DEBUG, "Resource %d %s %x-%x\n", idx,
 			       pci_dev->resource[idx].name,
-			       (unsigned long)pci_dev->resource[idx].start,
-			       (unsigned long)pci_dev->resource[idx].end);
+			       pci_resource_start(pci_dev, idx),
+			       pci_resource_end(pci_dev, idx));
 
 		memlen = pci_resource_len(pci_dev, idx);
 		if (memlen) {
-			adapter.dwRemappedMemBase[idx] =
+			adapter.apRemappedMemBase[idx] =
 			    ioremap(pci_resource_start(pci_dev, idx), memlen);
-			if (!adapter.dwRemappedMemBase[idx]) {
+			if (!adapter.apRemappedMemBase[idx]) {
 				HPI_DEBUG_LOG0(ERROR,
 					       "ioremap failed, aborting\n");
 				//unmap previously mapped pci mem space
 				goto err;
 			}
 		} else
-			adapter.dwRemappedMemBase[idx] = NULL;
+			adapter.apRemappedMemBase[idx] = NULL;
 
-		hm.u.s.Resource.r.Pci.dwMemBase[idx] =
-		    (__iomem u32) adapter.dwRemappedMemBase[idx];
+		Pci.apMemBase[idx] = adapter.apRemappedMemBase[idx];
 	}
 
+	Pci.wBusNumber = pci_dev->bus->number;
+	Pci.wVendorId = (u16) pci_dev->vendor;
+	Pci.wDeviceId = (u16) pci_dev->device;
+	Pci.wSubSysVendorId = (u16) (pci_dev->subsystem_vendor & 0xffff);
+	Pci.wSubSysDeviceId = (u16) (pci_dev->subsystem_device & 0xffff);
+	Pci.wDeviceNumber = pci_dev->devfn;
+	Pci.wInterrupt = pci_dev->irq;
+	Pci.pOsData = pci_dev;
+
 	hm.u.s.Resource.wBusType = HPI_BUS_PCI;
-	hm.u.s.Resource.r.Pci.wBusNumber = pci_dev->bus->number;
-	hm.u.s.Resource.r.Pci.wVendorId = (u16) pci_dev->vendor;
-	hm.u.s.Resource.r.Pci.wDeviceId = (u16) pci_dev->device;
-	hm.u.s.Resource.r.Pci.wSubSysVendorId =
-	    (u16) (pci_dev->subsystem_vendor & 0xffff);
-	hm.u.s.Resource.r.Pci.wSubSysDeviceId =
-	    (u16) (pci_dev->subsystem_device & 0xffff);
-	hm.u.s.Resource.r.Pci.wDeviceNumber = pci_dev->devfn;
-	hm.u.s.Resource.r.Pci.wInterrupt = pci_dev->irq;
-	hm.u.s.Resource.r.Pci.pOsData = (void *)pci_dev;
+	hm.u.s.Resource.r.Pci = &Pci;
 
 	//call CreateAdapterObject on the relevant hpi module
 	HPI_MessageEx(&hm, &hr, HOWNER_KERNEL);
 
-#if (COPY_TO_LOCAL)
+#if (HPIMOD_COPY_TO_LOCAL)
 	if ((adapter.pBuffer = vmalloc(bufsize)) == NULL) {
 		HPI_DEBUG_LOG1(ERROR,
 			       "HPI could not allocate kernel buffer size %d\n",
@@ -509,24 +526,28 @@ static int __devinit adapter_probe(struct pci_dev *pci_dev,
 
 		pci_set_drvdata(pci_dev, &adapters[hr.u.s.wAdapterIndex]);
 		adapter_count++;
+
 		return 0;
 	}
 
       err:
 	// missing code to delete adapter if error happens after creation (unlikely)
 	for (idx = 0; idx < HPI_MAX_ADAPTER_MEM_SPACES; idx++) {
-		if (adapter.dwRemappedMemBase[idx]) {
-			iounmap(adapter.dwRemappedMemBase[idx]);
-			adapter.dwRemappedMemBase[idx] = NULL;
+		if (adapter.apRemappedMemBase[idx]) {
+			iounmap(adapter.apRemappedMemBase[idx]);
+			adapter.apRemappedMemBase[idx] = NULL;
 		}
 	}
 
-#if (COPY_TO_LOCAL)
+#if (HPIMOD_COPY_TO_LOCAL)
 	if (adapter.pBuffer)
 		vfree(adapter.pBuffer);
 #endif
 
 	HPI_DEBUG_LOG0(ERROR, "adapter_probe failed\n");
+#if HPIMOD_PCI_ENABLE_DEV
+	pci_disable_device(pci_dev);
+#endif
 	return -ENODEV;
 }
 
@@ -549,13 +570,13 @@ static void __devexit adapter_remove(struct pci_dev *pci_dev)
 
 	// unmap PCI memory space, mapped during device init.
 	for (idx = 0; idx < HPI_MAX_ADAPTER_MEM_SPACES; idx++) {
-		if (pa->dwRemappedMemBase[idx]) {
-			iounmap(pa->dwRemappedMemBase[idx]);
-			pa->dwRemappedMemBase[idx] = NULL;
+		if (pa->apRemappedMemBase[idx]) {
+			iounmap(pa->apRemappedMemBase[idx]);
+			pa->apRemappedMemBase[idx] = NULL;
 		}
 	}
 
-#if (COPY_TO_LOCAL)
+#if (HPIMOD_COPY_TO_LOCAL)
 	if (pa->pBuffer)
 		vfree(pa->pBuffer);
 #endif
@@ -565,9 +586,18 @@ static void __devexit adapter_remove(struct pci_dev *pci_dev)
 	       "PCI device (%04x:%04x,%04x:%04x,%04x), HPI index # %d, removed.\n",
 	       pci_dev->vendor, pci_dev->device, pci_dev->subsystem_vendor,
 	       pci_dev->subsystem_device, pci_dev->devfn, pa->wAdapterIndex);
-
+#if HPIMOD_PCI_ENABLE_DEV
+	pci_release_regions(pci_dev);
+	pci_disable_device(pci_dev);
+#endif
 }
 
+// Module device table expects ints not pointers
+// Avoid having to cast the function pointers to long int
+#define HPI_4000 0x4000
+#define HPI_6000 0x6000
+#define HPI_6205 0x6205
+#define HPI_COMMON 0
 static struct pci_device_id asihpi_pci_tbl[] = {
 #include "hpipcida.h"
 };
@@ -618,14 +648,17 @@ static int __init hpimod_init(void)
 	/* HPI_DebugLevelSet(debug); now set directly as module param */
 	printk(KERN_INFO "ASIHPI driver %s debug=%d ",
 	       __stringify(DRIVER_VERSION), hpiDebugLevel);
-	printk("Spinlock on=%d Local copy=%d\n", USE_SPINLOCK, COPY_TO_LOCAL);
-	HPI_SubSysGetVersion(NULL, &dwVersion);
-	printk(KERN_INFO "HPI_SubSysGetVersion=%x\n", dwVersion);
+	printk("Spinlock on=%d Local copy=%d\n", USE_SPINLOCK,
+	       HPIMOD_COPY_TO_LOCAL);
+	HPI_SubSysGetVersionEx(NULL, &dwVersion);
+	printk(KERN_INFO "SubSys Version=%d.%02d.%02d\n",
+	       HPI_VER_MAJOR(dwVersion),
+	       HPI_VER_MINOR(dwVersion), HPI_VER_RELEASE(dwVersion));
 
 	HPI_InitMessage(&hm, HPI_OBJ_SUBSYSTEM, HPI_SUBSYS_DRIVER_LOAD);
 	HPI_MessageEx(&hm, &hr, HOWNER_KERNEL);
 
-	// old version of below fn returned +ve number of devices, -ve error 
+	// old version of below fn returned +ve number of devices, -ve error
 	if ((status = pci_register_driver(&asihpi_pci_driver)) < 0) {
 		HPI_DEBUG_LOG1(ERROR, "HPI: pci_register_driver returned %d\n",
 			       status);
